@@ -205,24 +205,25 @@ class HandyHelperListPlusCreateView(HandyHelperGenericBaseListView):
     A reusable generic base view to render a ListView where the child view will provide a html table and create form.
 
     class parameters:
-        base_template            - base template used for rendering page; defaults to: handyhelpers_base.htm
-        template_name            - template used when rendering page; defaults to: handyhelpers/generic/generic_list.html
-        args                     - additional args to pass into the template
-        kwargs                   - additional kwargs to pass into the template
-        queryset                 - queryset to be rendered on the page
-        title                    - title to use in template
-        page_description         - subtitle to use in template
-        table                    - htm file rendering the queryset to be included in the generic_list template
-        modals                   - htm file rendering additional modals to be included in the generic_list template
+        base_template              - base template used for rendering page; defaults to: handyhelpers_base.htm
+        template_name              - template used when rendering page; defaults to: handyhelpers/generic/generic_list.html
+        args                       - additional args to pass into the template
+        kwargs                     - additional kwargs to pass into the template
+        queryset                   - queryset to be rendered on the page
+        title                      - title to use in template
+        page_description           - subtitle to use in template
+        table                      - htm file rendering the queryset to be included in the generic_list template
+        modals                     - htm file rendering additional modals to be included in the generic_list template
 
-        create_form_obj          - form object
-        create_form_url          - url the form (action) should post to
-        create_form_title        - title to use on the create form modal (can be html)
-        create_form_modal        - name of modal for the create form
-        create_form_modal_size   - bootstrap modal size class (such as modal-lg)
-        create_form_link_title   - text used for the link opening the create form
-        create_form_tool_tip     - text to use for the tooltip
-        create_form_autocomplete - autocomplete parameter to use in form tag (on/off)
+        create_form_obj            - form object
+        create_form_url            - url the form (action) should post to
+        create_form_title          - title to use on the create form modal (can be html)
+        create_form_modal          - name of modal for the create form
+        create_form_modal_size     - bootstrap modal size class (such as modal-lg)
+        create_form_modal_backdrop - optional data-backdrop value(such as data-backdrop="static")
+        create_form_link_title     - text used for the link opening the create form
+        create_form_tool_tip       - text to use for the tooltip
+        create_form_autocomplete   - autocomplete parameter to use in form tag (on/off)
 
     example:
         class ListProjects(HandyHelperBaseCreateListView):
@@ -236,6 +237,7 @@ class HandyHelperListPlusCreateView(HandyHelperGenericBaseListView):
             create_form_title = '<b>Add Project: </b><small> </small>'
             create_form_modal = 'add_project'
             create_form_modal_size = 'modal-lg'
+            create_form_modal_backdrop = 'static'
             create_form_link_title = 'add project'
             create_form_tool_tip = 'add project'
     """
@@ -246,6 +248,7 @@ class HandyHelperListPlusCreateView(HandyHelperGenericBaseListView):
     create_form_title = None
     create_form_modal = None
     create_form_modal_size = None
+    create_form_modal_backdrop = None
     create_form_link_title = None
     create_form_tool_tip = None
     create_form_autocomplete = None
@@ -262,6 +265,7 @@ class HandyHelperListPlusCreateView(HandyHelperGenericBaseListView):
             self.create_form['title'] = self.create_form_title
             self.create_form['modal_name'] = self.create_form_modal
             self.create_form['modal_size'] = self.create_form_modal_size
+            self.create_form['modal_backdrop'] = self.create_form_modal_backdrop
             self.create_form['link_title'] = self.create_form_link_title
             self.create_form['tool_tip'] = self.create_form_tool_tip
             self.create_form['autocomplete'] = self.create_form_autocomplete
@@ -279,25 +283,26 @@ class HandyHelperListPlusFilterView(HandyHelperGenericBaseListView):
     A reusable generic base view to render a ListView where the child view will provide a html table and filter form.
 
     class parameters:
-        base_template            - base template used for rendering page; defaults to: handyhelpers_base.htm
-        template_name            - template used when rendering page; defaults to: handyhelpers/generic/generic_list.html
-        args                     - additional args to pass into the template
-        kwargs                   - additional kwargs to pass into the template
-        queryset                 - queryset to be rendered on the page
-        title                    - title to use in template
-        page_description         - subtitle to use in template
-        table                    - htm file rendering the queryset to be included in the generic_list template
-        modals                   - htm file rendering additional modals to be included in the generic_list template
+        base_template              - base template used for rendering page; defaults to: handyhelpers_base.htm
+        template_name              - template used when rendering page; defaults to: handyhelpers/generic/generic_list.html
+        args                       - additional args to pass into the template
+        kwargs                     - additional kwargs to pass into the template
+        queryset                   - queryset to be rendered on the page
+        title                      - title to use in template
+        page_description           - subtitle to use in template
+        table                      - htm file rendering the queryset to be included in the generic_list template
+        modals                     - htm file rendering additional modals to be included in the generic_list template
 
-        filter_form_obj          - form object
-        filter_form_url          - url the form (action) should post to
-        filter_form_title        - title to use on the filter form modal (can be html)
-        filter_form_modal        - name of modal for the filter form
-        filter_form_modal_size   - bootstrap modal size class (such as modal-lg)
-        filter_form_link_title   - text used for the link opening the filter form
-        filter_form_tool_tip     - text to use for the tooltip
-        filter_form_undo         - True
-        filter_form_autocomplete - autocomplete parameter to use in form tag (on/off)
+        filter_form_obj            - form object
+        filter_form_url            - url the form (action) should post to
+        filter_form_title          - title to use on the filter form modal (can be html)
+        filter_form_modal          - name of modal for the filter form
+        filter_form_modal_size     - bootstrap modal size class (such as modal-lg)
+        filter_form_modal_backdrop - optional data-backdrop value(such as data-backdrop="static")
+        filter_form_link_title     - text used for the link opening the filter form
+        filter_form_tool_tip       - text to use for the tooltip
+        filter_form_undo           - True
+        filter_form_autocomplete   - autocomplete parameter to use in form tag (on/off)
 
     example:
         class ListProjects(HandyHelperListPlusFilterView):
@@ -311,6 +316,7 @@ class HandyHelperListPlusFilterView(HandyHelperGenericBaseListView):
             filter_form_title = '<b>Filter Projects: </b><small> </small>'
             filter_form_modal = 'filter_project'
             filter_form_modal_size = 'modal-lg'
+            filter_form_modal_backdrop = 'static'
             filter_form_link_title = 'filter project'
             filter_form_tool_tip = 'filter project'
     """
@@ -321,6 +327,7 @@ class HandyHelperListPlusFilterView(HandyHelperGenericBaseListView):
     filter_form_title = None
     filter_form_modal = None
     filter_form_modal_size = None
+    filter_form_modal_backdrop = None
     filter_form_link_title = None
     filter_form_tool_tip = None
     filter_form_undo = True
@@ -338,6 +345,7 @@ class HandyHelperListPlusFilterView(HandyHelperGenericBaseListView):
             self.filter_form['title'] = self.filter_form_title
             self.filter_form['modal_name'] = self.filter_form_modal
             self.filter_form['modal_size'] = self.filter_form_modal_size
+            self.filter_form['modal_backdrop'] = self.filter_form_modal_backdrop
             self.filter_form['link_title'] = self.filter_form_link_title
             self.filter_form['tool_tip'] = self.filter_form_tool_tip
             self.filter_form['undo'] = self.filter_form_undo
@@ -352,34 +360,36 @@ class HandyHelperListPlusCreateAndFilterView(HandyHelperGenericBaseListView):
     and a create form and a filter form.
 
     class parameters:
-        base_template            - base template used for rendering page; defaults to: handyhelpers_base.htm
-        template_name            - template used when rendering page; defaults to: handyhelpers/generic/generic_list.html
-        args                     - additional args to pass into the template
-        kwargs                   - additional kwargs to pass into the template
-        queryset                 - queryset to be rendered on the page
-        title                    - title to use in template
-        page_description         - subtitle to use in template
-        table                    - htm file rendering the queryset to be included in the generic_list template
-        modals                   - htm file rendering additional modals to be included in the generic_list template
+        base_template              - base template used for rendering page; defaults to: handyhelpers_base.htm
+        template_name              - template used when rendering page; defaults to: handyhelpers/generic/generic_list.html
+        args                       - additional args to pass into the template
+        kwargs                     - additional kwargs to pass into the template
+        queryset                   - queryset to be rendered on the page
+        title                      - title to use in template
+        page_description           - subtitle to use in template
+        table                      - htm file rendering the queryset to be included in the generic_list template
+        modals                     - htm file rendering additional modals to be included in the generic_list template
 
-        create_form_obj          - create form object
-        create_form_url          - url the create form (action) should post to
-        create_form_title        - title to use on the create form modal (can be html)
-        create_form_modal        - name of modal for the create form
-        create_form_modal_size   - bootstrap modal size class (such as modal-lg)
-        create_form_link_title   - text used for the link opening the create form
-        create_form_tool_tip     - text to use for the create form link tooltip
-        create_form_autocomplete - autocomplete parameter to use in form tag (on/off)
+        create_form_obj            - create form object
+        create_form_url            - url the create form (action) should post to
+        create_form_title          - title to use on the create form modal (can be html)
+        create_form_modal          - name of modal for the create form
+        create_form_modal_size     - bootstrap modal size class (such as modal-lg)
+        create_form_modal_backdrop - optional data-backdrop value(such as data-backdrop="static")
+        create_form_link_title     - text used for the link opening the create form
+        create_form_tool_tip       - text to use for the create form link tooltip
+        create_form_autocomplete   - autocomplete parameter to use in form tag (on/off)
 
-        filter_form_obj          - filter form object
-        filter_form_url          - url the filter form (action) should post to
-        filter_form_title        - title to use on the filter form modal (can be html)
-        filter_form_modal        - name of modal for the filter form
-        filter_form_modal_size   - bootstrap modal size class (such as modal-lg)
-        filter_form_link_title   - text used for the link opening the filter form
-        filter_form_tool_tip     - text to use for the filter form link tooltip
-        filter_form_undo         - include an undo icon to clear applied filters
-        filter_form_autocomplete - autocomplete parameter to use in form tag (on/off)
+        filter_form_obj            - filter form object
+        filter_form_url            - url the filter form (action) should post to
+        filter_form_title          - title to use on the filter form modal (can be html)
+        filter_form_modal          - name of modal for the filter form
+        filter_form_modal_size     - bootstrap modal size class (such as modal-lg)
+        filter_form_modal_backdrop - optional data-backdrop value(such as data-backdrop="static")
+        filter_form_link_title     - text used for the link opening the filter form
+        filter_form_tool_tip       - text to use for the filter form link tooltip
+        filter_form_undo           - include an undo icon to clear applied filters
+        filter_form_autocomplete   - autocomplete parameter to use in form tag (on/off)
 
     example:
         class ListProjects(HandyHelperBaseCreateListView):
@@ -392,6 +402,7 @@ class HandyHelperListPlusCreateAndFilterView(HandyHelperGenericBaseListView):
             create_form_url = '/hostmgr/create_project/'
             create_form_title = '<b>Add Project: </b><small> </small>'
             create_form_modal = 'add_project'
+            create_form_modal_backdrop = 'static'
             create_form_link_title = 'add project'
             create_form_tool_tip = 'add project'
 
@@ -399,6 +410,7 @@ class HandyHelperListPlusCreateAndFilterView(HandyHelperGenericBaseListView):
             filter_form_url = '/hostmgr/filter_project/'
             filter_form_title = '<b>Filter Projects: </b><small> </small>'
             filter_form_modal = 'filter_projects'
+            filter_form_modal_backdrop = 'static'
             filter_form_link_title = 'filter projects'
             filter_form_tool_tip = 'filter projects'
             filter_form_undo = True
@@ -409,6 +421,7 @@ class HandyHelperListPlusCreateAndFilterView(HandyHelperGenericBaseListView):
     create_form_title = None
     create_form_modal = None
     create_form_modal_size = None
+    create_form_modal_backdrop = None
     create_form_link_title = None
     create_form_tool_tip = None
     create_form_autocomplete = None
@@ -419,6 +432,7 @@ class HandyHelperListPlusCreateAndFilterView(HandyHelperGenericBaseListView):
     filter_form_title = None
     filter_form_modal = None
     filter_form_modal_size = None
+    filter_form_modal_backdrop = None
     filter_form_link_title = None
     filter_form_tool_tip = None
     filter_form_undo = True
@@ -435,6 +449,7 @@ class HandyHelperListPlusCreateAndFilterView(HandyHelperGenericBaseListView):
             self.create_form['title'] = self.create_form_title
             self.create_form['modal_name'] = self.create_form_modal
             self.create_form['modal_size'] = self.create_form_modal_size
+            self.create_form['modal_backdrop'] = self.create_form_modal_backdrop
             self.create_form['link_title'] = self.create_form_link_title
             self.create_form['tool_tip'] = self.create_form_tool_tip
             self.create_form['autocomplete'] = self.create_form_autocomplete
@@ -447,6 +462,7 @@ class HandyHelperListPlusCreateAndFilterView(HandyHelperGenericBaseListView):
             self.filter_form['title'] = self.filter_form_title
             self.filter_form['modal_name'] = self.filter_form_modal
             self.filter_form['modal_size'] = self.filter_form_modal_size
+            self.filter_form['modal_backdrop'] = self.filter_form_modal_backdrop
             self.filter_form['link_title'] = self.filter_form_link_title
             self.filter_form['tool_tip'] = self.filter_form_tool_tip
             self.filter_form['undo'] = self.filter_form_undo
